Coverage for soxspipe/commonutils/getpackagepath.py: 50%

# Coverage for soxspipe/commonutils/getpackagepath.py : 50%

## 6 statements 3 run 3 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1#!/usr/bin/env python

2# encoding: utf-8

3"""

4*Get common file and folder paths for the host package*

5"""

6 import os

7

8

9 def getpackagepath():

10 """

11 *Get the root path for this python package*

12

13 Used in unit testing code

14 """

15 moduleDirectory = os.path.dirname(__file__)

16 packagePath = os.path.dirname(__file__) + "/../"

17

18 return packagePath